from setuptools import setup

setup(name='fagroupa',
      version='0.25',
      description='Try many sklearn algorithms in no time!',
      url='https://github.com/martinmaseda/fagroupa',
      author='Ivan Martin Maseda',
      author_email='ivan.martin@student.ie.edu',
      license='MIT',
      packages=['fagroupa'],
      zip_safe=False)
